#
# spec file for package python-yt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without test
%define psuffix -test
%else
%bcond_with test
%define psuffix %{nil}
%endif

# avoid "lto1: internal compiler error" during build
%global _lto_cflags %{nil}

%{?sle15_python_module_pythons}
Name:           python-yt%{psuffix}
Version:        4.4.0
Release:        1.5
Summary:        An analysis and visualization toolkit for volumetric data
License:        BSD-3-Clause
URL:            https://github.com/yt-project/yt
Source0:        https://files.pythonhosted.org/packages/source/y/yt/yt-%{version}.tar.gz
Source100:      python-yt-rpmlintrc
# PATCH-FIX-OPENSUSE yt-ignore-pytestdepr.patch code@bnavigator.de -- ignore a pytest deprecation warning. Upstream is still working on the nose ot pytest transition
Patch1:         yt-ignore-pytestdepr.patch
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  python-rpm-macros
%if !%{with test}
BuildRequires:  %{python_module Cython > 3 with %python-Cython < 3.1}
BuildRequires:  %{python_module ewah-bool-utils-devel >= 1.0.2}
BuildRequires:  %{python_module numpy-devel >= 1.25}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
%endif
Requires:       python-Pillow >= 8
Requires:       python-cmyt >= 1.1.2
Requires:       python-ewah-bool-utils >= 1.0.2
Requires:       python-ipywidgets >= 8.0.0
Requires:       python-matplotlib >= 3.5
Requires:       python-more-itertools >= 8.4
Requires:       python-numpy >= 1.19.3
Requires:       python-packaging >= 20.9
Requires:       python-tomli-w >= 0.4.0
Requires:       python-tqdm >= 3.4.0
Requires:       python-unyt >= 2.9.2
Requires:       (python-tomli >= 1.2.3 if python-base < 3.11)
Requires:       (python-typing-extensions >= 4.4.0 if python-base < 3.12)
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if %{with test}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pytest-mpl}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sympy}
BuildRequires:  %{python_module yt = %{version}}
# More optional modules for tests: scipy, pandas, h5py, xarray, glue, astropy, miniball, firefly, ...
%endif
%python_subpackages

%description
YT is an python package for analyzing and visualizing volumetric
data.  YT supports structured, variable-resolution meshes,
unstructured meshes, and discrete or sampled data such as particles.

%prep
%autosetup -p1 -n yt-%{version}
sed -i -e '/^#!\//, 1d' yt/utilities/lodgeit.py

%build
%if !%{with test}
export CFLAGS="%{optflags} -freport-bug"
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/yt
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%if %{with test}
%check
mv yt yt.src
# incompatible API attributes
donttest="test_default_species_fields or test_stream_species"
%{python_expand # need to use the compiled modules in the current directory because of skips defined in pyproject.toml
cp -r %{$python_sitearch}/yt yt
$python -m pytest yt -k "not ($donttest)"
rm -r yt
}
%endif

%post
%python_install_alternative yt

%postun
%python_uninstall_alternative yt

%if !%{with test}
%files %{python_files}
%doc README.md
%license COPYING.txt
%python_alternative %{_bindir}/yt
%{python_sitearch}/yt
%{python_sitearch}/yt-%{version}.dist-info
%endif

%changelog
* Sat Nov 23 2024 Dirk Müller <dmueller@suse.com>
- update to yt-4.4.0:
  * the frontend previously known as boxlib was renamed to AMReX
  * this release contains a brand new frontend for Parthenon
    datasets.
  * off-axis projections are now supported
  * improved convergence with grid resolution
  * improved mass conservation
  * fixed a critical bug where column densities estimates were
    incorrect by a factor x3
    calculation for Ramses, by @cphyc
  * Change in the way cooling tables are used. If "self-
    shielding" is detected from the namelist or is set by the
    user with `ds=yt.load("output_12345", self_shielding=True)`,
    the hydrogen number density used to obtain cooling, heating
    and $$\mu$$ from the cooling tables are multiplied by an
    exponential prefactor, consistently with what RAMSES is doing
    internally. This will change the values of the cooling and
    heating rates, as well as $$\mu$$ and temperature at high-
    densities (above 0.01 mp/cm³).
* Thu Jul 18 2024 Ben Greiner <code@bnavigator.de>
- Revert restriction. Numpy 2 is supported since 4.3.1
* Wed Jul 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2 for now.
* Thu Jul  4 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.3.1:
  * Fix broken urllib imports
  * Make annotate_sphere and annotate_arrow safe when run after plot
    invalidation
  * Fix an incompatibility with unyt 3.0 (amu_cgs doesn't exist as a physical
    constant anymore)
  * Handle deprecation warnings from numpy 2.0.0dev0 (np.row_stack ->
    np.vstack and np.in1d -> np.isin)
  * Avoid a deprecation warning in yt.load_sample on Python 3.12
  * Switch to field tuples for default fields in particle_trajectories
  * Enforce Figure dpi in _show_mpl
  * Fix bug where race condition results in incorrect fields categorization
    when computing particle_trajectories
  * Use the validated center for YTCuttingPlane set_field_parameter
  * Avoid usage of deprecated numpy.core namespace (numpy 2 compat)
  * Fix geographic coordinate conversions
  * Update xarray integration test to use non-deprecated API
  * Enzo testing framework - ignore units for ShockTube tests
  * Explicitly set minimum Python to 3.9.2
  * Ditch np.int_t, removed in numpy 2's C API (use np.int64_t instead)
  * Migrate module-level setup/teardown functions to pytest
- Drop patch yt-pr4727-unpin-unyt.patch, included upstream.
- Remove upper bound on numpy.
* Mon Apr  8 2024 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
* Wed Feb 14 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.3.0
  * This is the first version with support to CPython 3.12.
  * We've resolved all remaining compatibility issues with Cython
    3.
  [#]# New features
  * #4449 Add support for symlog colorbars with arbitrary bases, by
    @neutrinoceros (issue #4448)
  * #4455 Add support for passing field keys for colors and
    linewidth in streamline plot annotations, by @neutrinoceros
    (issue #4454)
  * #4527 Add QuadrilinearFieldInterpolator, by @brittonsmith
  * #4553 Store basic software info in png metadata, by @Xarthisius
  * #4556 Add option to include min/max limits on the color field
    for export_sketchfab, by @evenoconnor
  * #4658 Allow annotate_grids to force cmap to respect max_levels,
    by @zingale
  * #4642 + #4662 Make unused pixels actually transparent in all
    imshow-based 2D visualisations, by @neutrinoceros (issue #4639
    by @vdbma)
  * #4481 Add the ability to set the transfer function label
    fontsize, by @zingale
  [#]#  Frontends
  * #4562 Athena++ stretched grids support, by @jzuhone (issues
    [#1585] by @Yurlungur, #3389 by @smressle, #3619 by
    @neutrinoceros and #4557 by @matthewturk)
  * #4572 Species handling for the stream frontend, by @jzuhone
  * #4470 + #4605 Update GIZMO frontend to handle newer GIZMO
    versions, by @mtryan83
  * #4424 Support for sinks in csv format for RAMSES frontend, by
    @Lenoble-lab
- Release 4.2.x
  * This is the second feature release in the yt 4.x series. It
    also comes with some important bug fixes.
  * Some deprecations are now expired, some minor backward
    incompatibilities are expected. Anything broken on purpose in
    this version should correspond to a warning in yt 4.1.x,
    anything beyond that should be considered a regression; please
    report any unexpected breaking change.
  [#]# Highlights
  * Multiple improvements (detection, validation, uage) for EWAH
    files (#4307, #4426)
  * yt can now be installed with frontend specific optional
    dependencies with pip (#4272)
  * Plugin frontends can now seamlessly hook into yt.load() (#4285)
  * Off-axis projections are now supported for non-SPH particle
    (#4440)
  [#]# New features
  * #4175 Improvements to field_to_include specifications in
    create_firefly_object, by @mtryan83 (issue #4174)
  * #4198 + #4249 Automatically find EWAH files with increased
    index_order2, by @jzuhone (issue #3487 by @chummels)
  * #4205 Add upward directory lookup for local configuration file,
    by @neutrinoceros (issue #3953)
  * #4222 Two new features for writing FITS images, by @jzuhone
  * #4272 Add support for installing yt with cherry-picked,
    frontend specific optional dependencies with pip, by
    @neutrinoceros (issue #4272)
  * #4285 Automatically load external frontends in yt.load(), by
    @Xarthisius
  * #4307 Allow to store multiple bitmap indices in the
    ewah-sidecar, by @Xarthisius
  * #4343 Add reusable matplotlib stylesheet, by @neutrinoceros
    (issue #4342)
  * #4363 Add basename for loaders, by @jisuoqing
  * #4397 Allow hint keyword for yt.load to select superclasses, by
    @yut23
  * #4410 Export standard deviation to pandas DataFrames and
    AstroPy QTables, by @jzuhone
  * #4446 Whitelist the SPH star_formation_rate field, by @jzuhone
  * #4440 Off-axis (non-SPH) particle projections, by @jzuhone
- Add yt-pr4727-unpin-unyt.patch gh#yt-project/yt#4727
- Enable multibuild test flavor
- Add yt-ignore-pytestdepr.patch
* Tue Oct  3 2023 Ondřej Súkup <mimi.vx@gmail.com>
- Fix dependency on Cpython
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.4:
  * Fix calling PlotContainer.set_font to set font color,
  * Fix a regression in yt.load where '$HOME' and '~' path
    weren't expanded
  * (partial) Fix issue #4286 SDF frontend breaks load() if
    target file lacks read permission
  * (FLASH) Fix domain edges padding in reduced dimensions
  * (partial) Delay expensive imports
  * Cleanup calls to private methods _setup_plots in
    cookbook
* Mon Jan  2 2023 Matej Cepl <mcepl@suse.com>
- Upgrade to 4.1.3:
  This is the third bugfix release in the yt 4.1.x series. It
  contains fixes to bugs discovered since the 4.1.2 release. Most
  importantly, it reverts a unstable patch that was accidentally
  included in yt 4.1.2 (#4198). EWAH files should now behave as
  in yt 4.1.1, and we're aiming at re-releasing the new behaviour
  (with fixes) in yt 4.2.0
  - Bug fixes
  - #4231 Fix pixel size calculation for density option in
    particle projection plots and FITS images, by @jzuhone
  - #4239 Fix a broken docs example, by @neutrinoceros
  - Build and testing
  - #4247 ignore a deprecation warning triggered from cartopy,
    by @neutrinoceros
  - #4250 Revert "Backport PR #4198 on branch yt-4.1.x
    (Automatically find EWAH files with increased
    index_order2)", by @neutrinoceros
  - #4258 on branch yt-4.1.x, by @neutrinoceros
  - There are no new features or deprecations in this version,
    all users are encouraged to upgrade.
* Sat Dec  3 2022 Matej Cepl <mcepl@suse.com>
  DO NOT SUBMIT TO FACTORY, CFLAGS includes "-freport-bug"
- Upgrade to 4.1.2:
  It contains fixes to bugs discovered since the 4.1.1
  release. There are no new features or deprecations in this
  version, all users are encouraged to upgrade.
- Upgrade to 4.1.1:
  It contains a couple of critical fixes to bugs discovered since
  the 4.1.0 release. Most importantly, it resolves a memory leak
  that was affecting octree-based frontends (RAMSES and ART).
  There are no new features or deprecations in this version, all
  users are encouraged to upgrade.
- Upgrade to 4.1.0:
  It contains about a year of work by many contributors, with
  many new features and improvements to the code base. It is also
  the first release to officially supported Python 3.11.
  Some deprecations from yt < 4 are now expired, some minor
  backwards incompatibilities are expected. Anything broken on
  purpose in this version should correspond to a warning in yt
  4.0.x, anything beyond that should be considered a regression;
  please report any unexpected breaking change.
  Complete releases changelog is available at
  https://github.com/yt-project/yt/releases.
* Fri Jul 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 3.6.1
  * The angular momentum has been reversed compared to previous versions of yt.
    See `PR 2043 <https://github.com/yt-project/yt/pull/2043>`__.
  * New frontend support for the code AMRVAC. Many thanks to Clement Robert
    and Niels Claes who were major contributors to this initiative. Relevant PRs include:
  * Support for the AdaptaHOP halo finder code
    `PR 2385 <https://github.com/yt*project/yt/pull/2385>`__.
  * yt now supports geographic transforms and projections of data with
    cartopy with support from `PR 1966 <https://github.com/yt*project/yt/pull/1966>`__.
  * annotations used to work for only a single point, they now work for multiple points
    on a plot, see `PR 2122 <https://github.com/yt*project/yt/pull/2122>`__.
  * cosmology calculations now have support for the relativistic energy density of the
    universe, see `PR 1714 <https://github.com/yt*project/yt/pull/1714>`__.
    This feature is accessible to cosmology datasets and was added to the Enzo frontend.
  * the eps writer now allows for arrow rotation. this is accessible with
    the ``rotate`` kwarg in the ``arrow`` function.
    See `PR 2151 <https://github.com/yt*project/yt/pull/2151>`__.
  * allow for dynamic load balancing with parallel loading of timeseries
    data using the ``dynamic`` kwarg. `PR 2149 <https://github.com/yt*project/yt/pull/2149>`__.
  * show/hide colorbar and show/hide axes are now available for
    ``ProfilePlot`` s. These functions were also moved from the PlotWindow to the
    PlotContainer class. `PR 2169 <https://github.com/yt*project/yt/pull/2169>`__.
  * add support for ipywidgets with an ``__ipython_display__`` method on the
    FieldTypeContainer. Field variables, source, and the field array can be
    viewed with this widget. See PRs `PR 1844 <https://github.com/yt*project/yt/pull/1844>`__
    and `PR 1848 <https://github.com/yt*project/yt/pull/1848>`__,
    or try ``display(ds.fields)`` in a Jupyter notebook.
  * cut regions can now be made with ``exclude_`` and ``include_`` on a number of objects,
    including above and below values, inside or outside regions, equal values, or nans.
    See `PR 1964 <https://github.com/yt*project/yt/pull/1964>`__ and supporting
    documentation fix at `PR 2262 <https://github.com/yt*project/yt/pull/2262>`__.
  * previously aliased fluid vector fields in curvilinear geometries were not
    converted to curvilinear coordinates, this was addressed in
    `PR 2105 <https://github.com/yt*project/yt/pull/2105>`__.
  * 2d polar and 3d cylindrical geometries now support annotate_quivers,
    streamlines, line integral convolutions, see
    `PR 2105 <https://github.com/yt*project/yt/pull/2105>`__.
  * add support for exporting data to firefly `PR 2190 <https://github.com/yt-project/yt/pull/2190>`__.
  * gradient fields are now supported in curvilinear geometries. See
    `PR 2483 <https://github.com/yt*project/yt/pull/2483>`__.
  * plotwindow colorbars now utilize mathtext in their labels,
    from `PR 2516 <https://github.com/yt*project/yt/pull/2516>`__.
  * raise deprecation warning when using ``mylog.warn``. Instead use
    ``mylog.warning``. See `PR 2285 <https://github.com/yt*project/yt/pull/2285>`__.
  * extend support of the ``marker``, ``text``, ``line`` and ``sphere`` annotation
    callbacks to polar geometries  `PR 2466 <https://github.com/yt*project/yt/pull/2466>`__.
  * Support MHD in the GAMER frontend  `PR 2306 <https://github.com/yt-project/yt/pull/2306>`__.
  * Export data container and profile fields to AstroPy QTables and
    pandas DataFrames  `PR 2418 <https://github.com/yt*project/yt/pull/2418>`__.
  * Add turbo colormap, a colorblind safe version of jet.  See
    `PR 2339 <https://github.com/yt*project/yt/pull/2339>`__.
  * Enable exporting regular grids (i.e., covering grids, arbitrary grids and
    smoothed grids) to ``xarray`` `PR 2294 <https://github.com/yt*project/yt/pull/2294>`__.
  * add automatic loading of ``namelist.txt``, which contains the parameter file
    RAMSES uses to produce output `PR 2347 <https://github.com/yt*project/yt/pull/2347>`__.
  * adds support for a nearest neighbor value field, accessible with
    the ``add_nearest_neighbor_value_field`` function for particle fields. See
    `PR 2301 <https://github.com/yt*project/yt/pull/2301>`__.
  * speed up mesh deposition (uses caching) `PR 2136 <https://github.com/yt-project/yt/pull/2136>`__.
  * speed up ghost zone generation.  `PR 2403 <https://github.com/yt-project/yt/pull/2403>`__.
  * ensure that a series dataset has kwargs passed down to data objects `PR 2366 <https://github.com/yt-project/yt/pull/2366>`__.
- skip python36 because of numpy
* Fri May 15 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Mar 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.5.1:
  * no upstream changelog
* Tue Jan  8 2019 Todd R <toddrme2178@gmail.com>
- initial version
